@@ -17,8 +17,8 @@ class CalculatesMetricNecessities:
                 model.to(device)
                 model.eval()
                 logits = model(x)
-                sum_logits = logits if logits is None else sum_logits + logits
-            predictions = sum_logits.argmax(dim=1)
-            predictions.extend(predictions.cpu().numpy())
+                sum_logits = logits if sum_logits is None else sum_logits + logits
+            batch_predictions = sum_logits.argmax(dim=1)
+            predictions.extend(batch_predictions.cpu().numpy())
             labels.extend(y.cpu().numpy())
         return predictions, labels
