@@ -11,3 +11,7 @@ class ReportsLogits:
         for model in self.models:
             logits += model(x)
         return logits
+
+    @torch.no_grad()
+    def logits_(self, *args, **kwargs):
+        return self.logits(*args, **kwargs)
