@@ -1,9 +1,12 @@
 from torch import Tensor
 from torch.utils.data.dataloader import DataLoader
+from .HasLogits import HasLogits
+from .HasProbabilities import HasProbabilities
+from .HasLabels import HasLabels
 from ...device import get_device
 
 
-class Trainable:
+class Trainable(HasLogits, HasProbabilities, HasLabels):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
